import React, { Component } from "react";
import {
  Button,
  Form,
  Grid,
  Header,
  Image,
  Icon,
  Message,
} from "semantic-ui-react";
import { Redirect } from "react-router-dom";
import { Forms } from "../remote";

export default class ForgotPass extends Component {
  constructor(props) {
    super(props);
    this.state = {
      user: "",
      error: {
        state: false,
        message: [],
      },
      success: false,
    };
  }

  onChangeHandler = (event) => {
    let nam = event.target.name;
    let val = event.target.value;
    this.setState({ [nam]: val });
  };

  handleSendEmail = (e) => {
    e.preventDefault();

    Forms.submitInitResetPassword(this.state.user)
      .then(() => this.setState({ success: true }))
      .catch((err) =>
        this.setState({ error: { state: true, message: err.messages } })
      );
  };

  render() {
    if (this.state.success) {
      return <Redirect to="sent-email" />;
    }
    return (
      <React.Fragment>
        <Button circular style={{ margin: "2em" }} href="/">
          <Icon name="arrow alternate circle left" />
          Go Home{" "}
        </Button>
        <Grid
          textAlign="center"
          style={{ height: "70vh" }}
          verticalAlign="middle"
        >
          <Grid.Column style={{ maxWidth: 450 }}>
            <Header as="h2" color="blue" textAlign="center">
              <Image src="img/logo.png" /> Reset Password
            </Header>
            <Form
              size="large"
              style={{ marginTop: "2em" }}
              error={this.state.error.state}
            >
              <Message error>
                <Message.Header>Reset Password Error</Message.Header>

                {this.state.error.message.map((e, i) => (
                  <span key={i}>
                    {e}
                    <br />
                  </span>
                ))}
              </Message>
              <Form.Input
                icon="address card outline"
                iconPosition="left"
                placeholder="Enter your E-mail"
                name="user"
                type="text"
                onChange={this.onChangeHandler}
                required
              />
              <Button
                color="blue"
                fluid
                size="large"
                onClick={this.handleSendEmail}
              >
                Send E-mail
              </Button>
            </Form>
          </Grid.Column>
        </Grid>
      </React.Fragment>
    );
  }
}
